
log using "$logs/Divorce_CNEF.rtf", replace text

*-----------------------------------------------------------------------------*
*  MERGE CNEF DATASETS DATASET              		                          *
*-----------------------------------------------------------------------------*

use "$temp/gsoep.dta", clear

append using	"$temp/bhps.dta" "$temp/hilda.dta" 								///
				"$temp/psid.dta" "$temp/shp.dta", force

gen country = .
	replace country = 1 if study=="Britain"
	replace country = 2 if study=="Germany" & region_gsoep==1
	replace country = 3 if study=="Germany" & region_gsoep==2
	replace country = 4 if study=="Australia"
	replace country = 6 if study=="United States"
	replace country = 7 if study=="Switzerland"
	
merge m:1 country year using "$data/CNEF_CPI.dta", keep(1 3) nogen
	
cap drop country
encode study, gen(country)	

egen idnew = group(id country)
cap drop id
rename idnew id		

// Set Variables to Missing //
mvdecode 	gender age marstat nhhkid eduyrs wkhrs empstat lwgt sathealth ///
			srhealth lsat region_hilda region_shp, mv(-9/-1)
			
save "$temp/cnef.dta", replace

*-----------------------------------------------------------------------------*
*  Ouctome Variables: Log HHinc, Log LMinc, Rel. Pov., Life Satisfaction      *
*-----------------------------------------------------------------------------*

use "$temp/cnef.dta", clear

* Set Negative HH Incomes to Missing *
replace grhhinc = . if grhhinc<0
replace hhinc = . if hhinc<0
replace lminc = . if lminc<0

* Fill in CPI Values
cap drop group
egen group = group(country year) // 135 Groups
egen cpi_max = max(cpi), by(group)
drop cpi
rename cpi_max cpi

* Nominal Income
gen grnominc = grhhinc*(100/cpi)
lab var grnominc "HH Income"
gen lngrnominc = ln(grnominc + 1)
lab var lngrnominc "Gross Family Income"

gen nominc = hhinc*(100/cpi)
lab var nominc "Net Family Income"
gen lnnominc = ln(nominc + 1)
lab var lnnominc "Net Family Income"

gen lmnominc = lminc*(100/cpi)
lab var lmnominc "Labor Market Income"

**********************************
* Individual Labor Market Income *
**********************************

* Proportion of Individual Income to HH Income
gen proinc = lminc/grhhinc if !missing(lminc, grhhinc)
	replace proinc = 0 if (lminc==0 | grhhinc==0) & !missing(lminc, grhhinc)
lab var proinc "Prop. of Individual LM to HH Income"

*** Log Eq. Nominal HH Income ***
gen lnlminc = ln(lminc*(100/cpi))
lab var lnlminc "Log LM Income (Non-Eq.)"

**************************
* Gross Household Income *
**************************

*** Log Eq. Nominal HH Income ***
gen lngrhhinc = ln(grhhinc*(100/cpi))/(sqrt(nhh))
lab var lngrhhinc "Log Gross HH Income (Eq.)"

******************************
* Absolute Poverty (US Only) *
******************************

gen hhsize = nhh
merge m:1 hhsize year using "$data/povertythresholds.dta", keep(1 3) nogen
replace threshold = . if study!="United States"
cap drop hhsize

gen abpov = 1 if grhhinc<=threshold & !missing(grhhinc, threshold)
	replace abpov = 0 if grhhinc>threshold & !missing(grhhinc, threshold)
lab var abpov "Absolute Poverty (US Census)"
	
****************
* No Eq. Scale *
****************

* Generate Country-Year Median Eq. Incomes *
gen elevel = .
forvalues n = 1/135 {
	qui: sum hhinc [aw=cwgt] if group==`n', det
	replace elevel = r(p50) if group==`n'
}

*** Indicator Variable for Rel. Poverty ***
gen help = elevel*.6
gen relpov = 1 if hhinc<help & !missing(hhinc, help)
	replace relpov = 0 if hhinc>=help & !missing(hhinc, help)
lab var relpov "Relative Poverty (Non-Eq.)"
cap drop elevel help

*** Log Eq. Nominal HH Income ***
gen lnhhinc = ln(hhinc*(100/cpi))
lab var lnhhinc "Log HH Income (Non-Eq.)"

************************************
* Square-root of HH-Size Eq. Scale *
************************************

* Equivalize based on Number of HH Members *
gen eqhhinc = hhinc/(sqrt(nhh))

* Generate Country-Year Median Eq. Incomes *
gen elevel = .
forvalues n = 1/135 {
	qui: sum eqhhinc [aw=cwgt] if group==`n', det
	replace elevel = r(p50) if group==`n'
}

*** Indicator Variable for Eq. Rel. Poverty ***
gen help = elevel*.6
gen eqrelpov = 1 if eqhhinc<help & !missing(eqhhinc, help)
	replace eqrelpov = 0 if eqhhinc>=help & !missing(eqhhinc, help)
lab var eqrelpov "Relative Poverty (Eq.)"
cap drop elevel help

*** Log Eq. Nominal HH Income ***
replace eqhhinc = (hhinc*(100/cpi))/(sqrt(nhh))
gen lneqhhinc = ln(eqhhinc)
lab var lneqhhinc "Log HH Income (Eq.)"
	
******************
* OECD Eq. Scale *
******************

* Equivalize based on HH Composition *
cap drop equiv
gen equiv = 1 + (0.7 * (nhh - nhhkid - 1)) + (0.5 * nhhkid)
gen eqhhinc2 = hhinc/equiv

* Generate Country-Year Median Eq. Incomes *
cap drop elevel
gen elevel = .
forvalues n = 1/135 {
	qui: sum eqhhinc2 [aw=cwgt] if group==`n', det
	replace elevel = r(p50) if group==`n'
}

*** Indicator Variable for Eq. Rel. Poverty ***
gen help = elevel*.6
gen eqrelpov2 = 1 if eqhhinc2<help & !missing(eqhhinc2, help)
	replace eqrelpov2 = 0 if eqhhinc2>=help & !missing(eqhhinc2, help)
lab var eqrelpov2 "Relative Poverty (OECD Eq.)"

*** Log Eq. Nominal HH Income ***
replace eqhhinc2 = (hhinc*(100/cpi))/equiv
gen lneqhhinc2 = ln(eqhhinc2)
lab var lneqhhinc2 "Log HH Income (OECD Eq.)"

save "$temp/cnef_inc.dta", replace

*-----------------------------------------------------------------------------*
*  Select sample                                                              *
*-----------------------------------------------------------------------------*

use "$temp/cnef_inc.dta", clear

// Drop Men //
drop if gender==1

// Use to drop specific subsamples: //
// subsamp_gsoep subsamp_bhps subsamp_psid subsamp_shp //
drop if subsamp_gsoep==27

* Age selection
label variable age "Age in years"

* Birth Year
gen birthy = year - age
label variable birthy "Year of Birth"

* Marital status - Not with Partner -> Single, Seperated -> Divorced
recode marstat (6 7 = 2) (5 = 4) (9 = .)	

* Select persons who divorce across the observation window

** Year in which first observed in divorce
gen year_long = year if marstat==4
bysort id (year): egen year_wide = min(year_long)

** Define indicator variable for first observations of marital status divorced
gen div = 0
replace div = 1 if year_long==year_wide & year_long!=. 
label variable div "First observation in divorce"
drop year_long year_wide

** Drop persons who are divorced upon first observation
bysort id (year): gen n = _n
gen aux = n == 1 & div==1 // Drop condition: First obs. is first obs in divorce
bysort id (year): egen aux1 = max(aux)
drop if aux1==1
drop aux aux1

** Mark  persons observed across the transition from married to divorced
bysort id (year): egen sample = max(div)
label variable sample "Sample: Persons experiencing divorce"

** Mark observation before divorce
gen aux = n if div==1 	// Number of the observation of the initial transition
replace aux = aux - 1 	// Observation before the initial transition
bysort id: egen aux1 = max(aux)
gen beforediv = aux1 == n
label variable beforediv "Last observation before divorce"
drop aux aux1 n

** Restrict to those experiencing divorce or married
keep if marstat==1 | marstat==4

*-----------------------------------------------------------------------------*
*  Analytic variables                                                         *
*-----------------------------------------------------------------------------*

* Time
** Generate an index variable counting the years before and after divorce
gen aux = year if div==1 
bysort id (year): egen year_div = max(aux) // year of divorce
label variable year_div "Year of Divorce"
bysort id (year): gen index = year - year_div 
label variable index "Years before/after divorce"
drop aux

** Generate divorce dummy
gen d = 0
replace d = 1 if index>=0 & sample==1
label variable d "Divorce dummy"

** Generate duration variable for years after divorce
gen dur = index
replace dur = 0 if dur<1
	replace dur = 0 if sample==0		// Duration of zero if Non-Divorcee
label variable dur "Years after divorce"

*-----------------------------------------------------------------------------*
*  Moderator variables                                                        *
*-----------------------------------------------------------------------------*

* Number of children in the year of divorce
gen aux = nhhkid if year_div==year & sample==1
	bys id: egen nhhkid_red = max(aux) if sample==1
	cap drop aux
* Max Number of Children for Non-Divorcees
bys id: egen aux = max(nhhkid) if sample==0 
	replace nhhkid_red = aux if nhhkid_red==. & sample==0
	cap drop aux
	
* Alternative Child Measure - Up to 6 Children
gen nhhkid_red2 = nhhkid_red
	replace nhhkid_red2 = 6 if nhhkid_red2>6 & nhhkid_red2!=.
	
* Only up to three children
replace nhhkid_red = 3 if nhhkid_red>3 & nhhkid_red!=.

* Mother Dummy
gen mom = 1 if nhhkid_red>0 & nhhkid_red!=.
	replace mom = 0 if nhhkid_red==0
cap lab drop mom
lab def mom 0"Childless" 1"Mother"
lab val mom mom
lab var mom "Motherhood Dummy"

*-----------------------------------------------------------------------------*
*  Control variables                                                          *
*-----------------------------------------------------------------------------*

* Year of divorce
gen y2010 = year_div - 2010
label variable y2010 "Year of Divorce (centered at 2010)"

* Age at Divorce (Drop Divorces between Age 18-60)
gen temp = age if year_div==year
bys id: egen age_at = mean(temp)
cap drop temp
label variable age_at "Age at Divorce"
drop if (age_at<18 | age_at>50) & sample==1

* Age (Bin) of the Youngest Child
gen kidage = .
	replace kidage = 7 if nhh_16_18>0 & !missing(nhh_16_18)
	replace kidage = 6 if nhh_13_15>0 & !missing(nhh_13_15)
	replace kidage = 5 if nhh_11_12>0 & !missing(nhh_11_12)
	replace kidage = 4 if nhh_8_10>0 & !missing(nhh_8_10)
	replace kidage = 3 if nhh_5_7>0 & !missing(nhh_5_7)
	replace kidage = 2 if nhh_2_4>0 & !missing(nhh_2_4)
	replace kidage = 1 if nhh_0_1>0 & !missing(nhh_0_1)
	replace kidage = 0 if nhhkid==0
lab var kidage "Age of Youngest Child"
cap lab drop kidage
lab def kidage																///
	0"No Children" 1"0-1" 2"2-4" 3"5-7" 4"8-10" 5"11-12" 6"13-15" 7"16-18"
lab val kidage kidage

* Re-Marriage Indicator
gen mstat = 0 if index<=0 | (sample==1 & marstat==4)
	replace mstat = 1 if sample==1 & index>0 & marstat==1
	replace mstat = 0 if sample==0
lab var mstat "Remarriage Indicator"

* Average Work Hours (Top Coded, 0 for Non-Employed)
sum wkhrs, det
replace wkhrs = . if wkhrs>`r(p99)'
replace wkhrs = 0 if empstat==0

*-----------------------------------------------------------------------------*
* Create Mean Centered & Deviation Variables for Time-Varying Variables       *
* Unconditional Models with Time-Constant Number of Children                  *
*-----------------------------------------------------------------------------*

* Keep if Age between 18 & 65
drop if age<18 | age>65	

* Transform Age Variable, 0 = Age 35 *
replace age = age - 35

* Mean Center & Devation Variables	
bys id: egen d_m = mean(d)
	
bys id: egen dur_m = mean(dur)
	
bys id: egen age_m = mean(age)
	gen age_d = age - age_m
	
* Transform Year Variable, 0 = 2010
	gen y10 = year - 2010
bys id: egen yr_m = mean(y10)
	gen yr_d = y10 - yr_m
	
*-----------------------------------------------------------------------------*
*-----------------------------------------------------------------------------*

* Save
save "$temp/cnef_analysis", replace	

log close
