
log using "$logs/Divorce_CNEF.rtf", append text

*-----------------------------------------------------------------------------*
* Identify Cohabitors in PSID												  *
*-----------------------------------------------------------------------------*

use "$temp/psid.dta", clear

* Keep only HH heads and partners
keep if relation==1 | relation==2

* Count number of HH members
bys hhid year: gen n = _N
drop if n>2

* Generate cohabitation indicator
recode n (1 = 0 "Single") (2 = 1 "Cohabiting"), gen(cohab)
lab var cohab "Cohabitation Indicator"
drop n

// Drop Men //
drop if gender==1

* Age selection
label variable age "Age in years"

* Birth Year
gen birthy = year - age
label variable birthy "Year of Birth"

* Select persons who seperate across the observation window
** Year in which first observed in seperation
bys id (year): gen year_wide = year if cohab==0 & cohab[_n-1]==1

** Define indicator variable for first observations of marital status divorced
gen sep = 0
replace sep = 1 if year==year_wide
label variable sep "First observation in separation"

** Drop those experiencing divorce or married
bys id (year): gen aux = 1 if sep==1 & marstat[_n-1]==1
bys id (year): egen aux1 = max(aux)
drop if aux1==1
drop year_wide aux aux1

** Drop persons who are divorced upon first observation
*bysort id (year): gen n = _n
*gen aux = n == 1 & div==1 // Drop condition: First obs. is first obs in divorce
*bysort id (year): egen aux1 = max(aux)
*drop if aux1==1
*drop aux aux1

** Mark  persons observed across the transition from married to divorced
bysort id (year): egen sample = max(sep)
label variable sample "Sample: Persons experiencing separation"

** Keep continously cohabiting but not married as control sample
drop if sample==0 & cohab==0
drop if sample==0 & marstat==1

** Mark observation before divorce
*gen aux = n if sep==1 	// Number of the observation of the initial transition
*replace aux = aux - 1 	// Observation before the initial transition
*bysort id: egen aux1 = max(aux)
*gen beforesep = aux1 == n
*label variable beforesep "Last observation before seperation"
*drop aux aux1 n

*-----------------------------------------------------------------------------*
*  Analytic variables                                                         *
*-----------------------------------------------------------------------------*

* Time
** Generate an index variable counting the years before and after divorce
gen aux = year if sep==1 
bysort id (year): egen year_sep = max(aux) // year of divorce
label variable year_sep "Year of Separation"
bysort id (year): gen index = year - year_sep 
label variable index "Years before/after separation"
drop aux

** Generate divorce dummy
gen s = 0
replace s = 1 if index>=0 & sample==1
label variable s "Seperation dummy"

** Generate duration variable for years after divorce
gen dur = index
replace dur = 0 if dur<1
	replace dur = 0 if sample==0		// Duration of zero if Non-Divorcee
label variable dur "Years after separation"

** Keep observations with only one seperation
bys id (year): egen sep_n = total(sep)
drop if sep_n>1
drop sep_n

** Drop double households
bys hhid year: drop if _N>1

*-----------------------------------------------------------------------------*
*  Moderator variables                                                        *
*-----------------------------------------------------------------------------*

* Same as above for number of children in the year of divorce
gen help = nhhkid if year_sep==year & sample==1
	bys id: egen nhhkid_red = max(help) if sample==1
	cap drop help
* Max Number of Children for Non-Divorcees
bys id: egen help = max(nhhkid) if sample==0 
	replace nhhkid_red = help if nhhkid_red==. & sample==0
	cap drop help
* Only up to three children
replace nhhkid_red = 3 if nhhkid_red>3 & nhhkid_red!=.

* Mother Dummy
gen mom = 1 if nhhkid_red>0 & nhhkid_red!=.
	replace mom = 0 if nhhkid_red==0
cap lab drop mom
lab def mom 0"Childless" 1"Mother"
lab val mom mom
lab var mom "Motherhood Dummy"

*-----------------------------------------------------------------------------*
*  Control variables                                                          *
*-----------------------------------------------------------------------------*

* Age at Divorce (Drop Divorces between Age 18-60)
gen temp = age if year_sep==year
bys id: egen age_at = mean(temp)
cap drop temp
label variable age_at "Age at Divorce"
drop if (age_at<18 | age_at>50) & sample==1

*-----------------------------------------------------------------------------*
* Create Mean Centered & Deviation Variables for Time-Varying Variables       *
* Unconditional Models with Time-Constant Number of Children                  *
*-----------------------------------------------------------------------------*

* Keep if Age between 18 & 65
drop if age<18 | age>65	

* Transform Age Variable, 0 = Age 35 *
replace age = age - 35

* Mean Center & Devation Variables	
bys id: egen s_m = mean(d)
	
bys id: egen dur_m = mean(dur)
	
bys id: egen age_m = mean(age)
	gen age_d = age - age_m
	
* Transform Year Variable, 0 = 2010
	gen y10 = year - 2010
bys id: egen yr_m = mean(y10)
	gen yr_d = y10 - yr_m

*-----------------------------------------------------------------------------*
*  Merge poverty variable                                                     *
*-----------------------------------------------------------------------------*

merge 1:m hhid year study using "$temp/cnef_inc.dta",							///
	keepusing(lngrnominc) keep(1 3) nogen
bys hhid year: drop if _n>1

* Save
save "$temp/cohab_analysis", replace	

*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*
* Unconditional Hybrid RE Models on Poverty 								   *
*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*

foreach y in lngrnominc {

local z: variable label `y'

use "$temp/cohab_analysis", clear
xtset id year

*------------------------------------------------------------------------------*
* Motherhood  															       *
*------------------------------------------------------------------------------*

mixed `y'																		///
	c.s_m i.s																	///
	c.dur_m c.dur																///
		i.mom																	///
		c.s_m#i.mom i.s#i.mom													///
		c.dur_m#i.mom c.dur#i.mom												///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///	
						|| id: , mle
						 
est store mixed												

*** Plot Predictions by Motherhood & Divorce Status ***
est restore mixed
margins,																		///
		at(s=(0) dur=(-1) sample=(1))											///
		at(s=(1) dur=(0) sample=(1)) 											///
		at(s=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(mom) expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(gs10)) 										///
	plot2opts(lpattern(solid) lcolor(gs10))										///
	xtitle("Years Following Separation", size(small)) 							///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(3 "Childless" 4 "Mother") position(6) row(1))					
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_p_coh.png", replace
	
* Calculate & Plot Predictions by Motherhood & Divorce Status *

forvalues j = 0/1 {

	est restore mixed
	margins, dydx(s) at(dur=(0) mom=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.s]
		gen LB`j'_1 = _b[0b.s] - 1.96*_se[0b.s]
		gen UB`j'_1 = _b[0b.s] + 1.96*_se[0b.s]
		gen B`j'_2 = _b[1.s]
		gen LB`j'_2 = _b[1.s] - 1.96*_se[1.s]
		gen UB`j'_2 = _b[1.s] + 1.96*_se[1.s]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed	
		margins, dydx(dur) at(s=(1) dur=(`m') mom=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}

* Calculate & Plot Motherhood Effect by Divorce Duration *
est restore mixed
margins, dydx(mom) at(s=(0) dur=(0) sample=(1)) post

	gen C_1 = _b[1.mom]
	gen CLB_1 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_1 = _b[1.mom] + _se[1.mom]*1.96

est restore mixed
margins, dydx(mom) at(s=(1) dur=(0) sample=(1)) post

	gen C_2 = _b[1.mom]
	gen CLB_2 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_2 = _b[1.mom] + _se[1.mom]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(mom) at(s=(1) dur=(`m') sample=(1)) post
	
	gen C_`i' = _b[1.mom]
	gen CLB_`i' = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_`i' = _b[1.mom] + _se[1.mom]*1.96	
	
	local i = `i' + 1
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_ C_ CLB_ CUB_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB, i(T) j(mom)

bys mom (T): replace B = B[_n-1] + B if T>=1
bys mom (T): replace LB = LB[_n-1] + LB if T>=1
bys mom (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if mom==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if mom==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline LB UB T if mom==1, 												///
		lpattern(dot) lcolor(gs10)												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' following Separation (%)", size(small)) 			///
		yscale(range(-100(20)40)) ylabel(-100(20)40)							///
		xtitle("Years Following Separation", size(small))						///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Childless" 3 "Mother") position(6) row(1))															
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_c_coh.png", replace

tw 	line C T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline CLB CUB T if mom==1, 												///
		lpattern(dot) lcolor(gs10) 												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' rel. to Childless Women (%)", size(small)) 	///
		yscale(range(-100(20)40)) ylabel(-100(20)40)							///
		xtitle("Years Following Separation", size(small))						///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Mother") position(6) row(1))															
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_d_coh.png", replace

*------------------------------------------------------------------------------*
* Number of Children													       *
*------------------------------------------------------------------------------*

use "$temp/cohab_analysis", clear

mixed `y'																		///
	c.s_m i.s																	///
	c.dur_m c.dur																///
		i.nhhkid_red															///
		c.s_m#i.nhhkid_red i.s#i.nhhkid_red										///
		c.dur_m#i.nhhkid_red c.dur#i.nhhkid_red									///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///	
						|| id: , mle
						 
est store mixed
	
*** Plot Predictions by Family Size & Divorce Status ***
est restore mixed
margins,																		///
		at(s=(0) dur=(-1) sample=(1))											///
		at(s=(1) dur=(0) sample=(1)) 											///
		at(s=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(nhhkid_red) expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(ananas)) 										///
	plot2opts(lpattern(solid) lcolor(ananas))									///
	ci3opts(lpattern(dot) lcolor(orangebrown)) 									///
	plot3opts(lpattern(solid) lcolor(orangebrown))								///
	ci4opts(lpattern(dot) lcolor(vermillion)) 									///
	plot4opts(lpattern(solid) lcolor(vermillion))								///
	xtitle("Years Following Separation", size(small)) 							///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(5 "0" 6 "1" 7 "2" 8 "3+") 										///
	title("Number of Children", size(small)) position(6) row(1))
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_p_coh.png", replace
	
*** Calculate & Plot Predictions by Family Size & Divorce Status ***
forvalues j = 0/3 {

	est restore mixed
	margins, dydx(s) at(dur=(0) nhhkid_red=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.s]
		gen LB`j'_1 = _b[0b.s] - 1.96*_se[0b.s]
		gen UB`j'_1 = _b[0b.s] + 1.96*_se[0b.s]
		gen B`j'_2 = _b[1.s]
		gen LB`j'_2 = _b[1.s] - 1.96*_se[1.s]
		gen UB`j'_2 = _b[1.s] + 1.96*_se[1.s]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed		
		margins, dydx(dur) at(s=(1) dur=(`m') nhhkid_red=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}

* Calculate & Plot Motherhood Effect by Divorce Duration *
forvalues j = 1/3 {

est restore mixed
margins, dydx(`j'.nhhkid_red) at(s=(0) dur=(0) sample=(1)) post

	gen C`j'_1 = _b[`j'.nhhkid_red]
	gen CLB`j'_1 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_1 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

est restore mixed
margins, dydx(`j'.nhhkid_red) at(s=(1) dur=(0) sample=(1)) post

	gen C`j'_2 = _b[`j'.nhhkid_red]
	gen CLB`j'_2 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_2 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(`j'.nhhkid_red) at(s=(1) dur=(`m') sample=(1)) post
	
	gen C`j'_`i' = _b[`j'.nhhkid_red]
	gen CLB`j'_`i' = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_`i' = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96	
	
	local i = `i' + 1
}
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_										///
			 B2_ LB2_ UB2_ B3_ LB3_ UB3_										///
			 C1_ CLB1_ CUB1_ C2_ CLB2_ CUB2_									///
			 C3_ CLB3_ CUB3_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB C CLB CUB, i(T) j(kid)

bys kid (T): replace B = B[_n-1] + B if T>=1
bys kid (T): replace LB = LB[_n-1] + LB if T>=1
bys kid (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB  C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if kid==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if kid==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline LB UB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line B T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline LB UB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line B T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline LB UB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' following Separation (%)", size(small)) 			///
		yscale(range(-100(20)40)) ylabel(-100(20)40)							///
		xtitle("Years Following Separation", size(small))						///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "0" 3 "1" 5 "2" 7 "3+") 									///
		title("Number of Children", size(small)) position(6) row(1))
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_c_coh.png", replace

tw	 line C T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline CLB CUB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line C T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline CLB CUB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line C T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline CLB CUB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' rel. to Childless Women (%)", size(small)) 	///
		yscale(range(-100(20)40)) ylabel(-100(20)40)							///
		xtitle("Years Following Separation", size(small))						///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "1" 3 "2" 5 "3+") 										///
		title("Number of Children", size(small)) position(6) row(1))
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_d_coh.png", replace

use "$temp/cnef_analysis.dta", clear

}

log close
